<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

use XrayProfiler\Log;
use XrayProfiler\CollectorShortcode;

if (defined('ABSPATH') && defined('WPINC') && function_exists('add_filter') && function_exists('json_encode')) {
    try {
        include 'classes/xray-profiler-log.php';
        include 'classes/xray-profiler-collector.php';
        include 'classes/xray-profiler-collector-shortcodes.php';

        if (!function_exists('xray_profiler_set_error_handler')) {
            /**
             * @return void
             */
            function xray_profiler_set_error_handler()
            {
                set_error_handler(function ($err_no, $err_str) {
                    if (class_exists('\XrayProfiler\Log')) {
                        Log::instance()->setData($err_no . ': ' . $err_str);
                    }
                    return true;
                }, E_ALL);
            }
        }

        if (!function_exists('xray_profiler_restore_error_handler')) {
            /**
             * @return void
             */
            function xray_profiler_restore_error_handler()
            {
                restore_error_handler();
            }
        }

        if (!function_exists('xray_profiler_get_shortcodes_data')) {
            /**
             * @return string
             */
            function xray_profiler_get_shortcodes_data()
            {
                $result = '';

                if (class_exists('\XrayProfiler\CollectorShortcode')) {
                    xray_profiler_set_error_handler();

                    $xray_data = [
                        'shortcodes' => CollectorShortcode::instance()->getXrayData(),
                    ];

                    if (!($json = json_encode($xray_data))) {
                        if (class_exists('\XrayProfiler\Log')) {
                            Log::instance()->setData("Can't prepare json for " . __METHOD__);
                        }
                    } else {
                        $result = $json;
                    }

                    xray_profiler_restore_error_handler();
                }

                return $result;
            }
        }

        // Filters
        if (class_exists('\XrayProfiler\CollectorShortcode')) {
            $priority = defined('PHP_INT_MIN') ? PHP_INT_MIN : 0 - PHP_INT_MAX;

            add_filter('pre_do_shortcode_tag', function ($return, $tag, $attr, $m) {
                xray_profiler_set_error_handler();
                $return = CollectorShortcode::instance()->preDoShortcodeTagEarly($return, $tag, $attr, $m);
                xray_profiler_restore_error_handler();
                return $return;
            }, $priority, 4);

            add_filter('pre_do_shortcode_tag', function ($return, $tag, $attr, $m) {
                xray_profiler_set_error_handler();
                $return = CollectorShortcode::instance()->preDoShortcodeTagLate($return, $tag, $attr, $m);
                xray_profiler_restore_error_handler();
                return $return;
            }, PHP_INT_MAX, 4);

            add_filter('do_shortcode_tag', function ($output, $tag, $attr, $m) {
                xray_profiler_set_error_handler();
                $output = CollectorShortcode::instance()->doShortcodeTagLate($output, $tag, $attr, $m);
                xray_profiler_restore_error_handler();
                return $output;
            }, PHP_INT_MAX, 4);
        }
    } catch (Exception $e) {
        // ...
    }
}
